@@ -174,13 +174,23 @@ def __get_bounds(function_name = None,steps = 200,*args):
 
 def lognormal(mean, var, steps = 200):
 
-    args = list(args)
-    for i in range(0,len(args)):
-        if args[i].__class__.__name__ != 'Interval':
-            args[i] = Interval(args[i])
+    x = np.linspace(0.001,0.999,steps)
 
-    Left, Right, mean, var = __get_bounds('lognormal',steps,*args)
+    if mean.__class__.__name__ != 'Interval':
+        mean = Interval(mean,mean)
+    if var.__class__.__name__ != 'Interval':
+        var = Interval(var,var)
 
+    bound0 = sps.lognorm.ppf(x, mean.left, var.left)
+    bound1 = sps.lognorm.ppf(x, mean.right, var.left)
+    bound2 = sps.lognorm.ppf(x, mean.left, var.right)
+    bound3 = sps.lognorm.ppf(x, mean.right, var.right)
+
+    Left = [min(bound0[i],bound1[i],bound2[i],bound3[i]) for i in range(steps)]
+    Right = [max(bound0[i],bound1[i],bound2[i],bound3[i]) for i in range(steps)]
+
+    Left = np.array(Left)
+    Right = np.array(Right)
     return Pbox(
         Left,
         Right,
